yakumo.neutron.v2.lb.vip.Manager

Package yakumo :: Package neutron :: Package v2 :: Package lb :: Module vip :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
     base.SubManager --+
                       |
                      Manager

Manager class for LB virtual IPs in Networking V2 API

Nested Classes | [hide private]
| resource_class Resource class for LB virtual IPs in Networking V2 API

Instance Methods | [hide private]
yakumo.neutron.v2.lb.vip.Resource |
create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, subnet=`'``__UNDEF__``'`, address=`'``__UNDEF__``'`, protocol=`'``__UNDEF__``'`, protocol_port=`'``__UNDEF__``'`, session_persistence=`'``__UNDEF__``'`, connection_limit=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) Create a VIP for a LB pool | source code
_find_gen(self, **kwargs) | source code
Inherited from `base.SubManager`: `__init__` Inherited from `base.Manager`: `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``vip``'``
| _json_resources_key = ``'``vips``'``
| _url_resource_path = ``'``/v2.0/lb/vips``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, subnet=`'``__UNDEF__``'`, address=`'``__UNDEF__``'`, protocol=`'``__UNDEF__``'`, protocol_port=`'``__UNDEF__``'`, session_persistence=`'``__UNDEF__``'`, connection_limit=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) | source code
Create a VIP for a LB pool Parameters: `name` - VIP name :param name: str `description` - VIP description :param description: str `subnet` - Subnet object (required) :param subnet: yakumo.neutron.v2.subnet.Resource `address` - Address :param address: str `protocol` - Protocol; 'TCP', 'HTTP', or 'HTTPS' (required) :param protocol: str `protocol_port` - Port number :param protocol_port: int `pool` - LB pool :param pool: yakumo.neutron.v2.lb_pool.Resource `is_session_persistent` - Whether the session is persistent :param is_session_persistent: bool `connection_limit` - Maximum connection number :param connection_limit: int `is_enabled` - Whether the VIP is enabled :param is_enabled: bool Returns: yakumo.neutron.v2.lb.vip.Resource Created VIP Overrides: base.Manager.create

### _find_gen(self, **kwargs) | source code
Overrides: base.Manager._find_gen

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('protocol', 'protocol', mapper.Noop
      ), ('address', 'address', mapper.Noop), ('protocol_port', 'protocol_po
      rt', mapper.Noop), ('connection_limit', 'connection_limit', mapper.Noo
      p), ('pool', 'pool_id', mapper.Resource('neutron.lb.pool')), ('subnet'
      , 'subnet_id', mapper.Resource('neutron.subnet')), ('project', 'tenant
      _id', mapper.Resource('project')), ('port', 'port_id', mapper.Resource
      ('neutron.port')), ('is_enabled', 'admin_state_up', mapper.Noop), ('is
      ...